#' bezier.amira.set
#'
#' This function finds n evenly spaced points from a landmark set file exported from Amira (.landmarkAscii)
#' @param name.file character: path of the landmark set file (.landmarkAscii)
#' @param npoint numeric: number of evenly spaced points desired
#' @param mag numeric: number of iterations for \code{\link{dec.curve}} 
#' @return evenly.set numeric: matrix with evenly-spaced landmark coordinates (kxm)
#' @author Antonio Profico, Alessio Veneziano
#' @export
bezier.amira.set=function(name.file,nland,npoint,mag=3){
mat.bezier=read.amira.set(name.file,nland)
if(is.null(mag)==TRUE){
evenly.set=pointsOnBezier(mat.bezier[,,1],n=npoint)$points  
} 
if(is.numeric(mag)==TRUE){dec.mat.bezier=dec.curve(mat.bezier[,,1],mag,plot=FALSE)
evenly.set=pointsOnBezier(dec.mat.bezier,n=npoint)$points}
return(evenly.set)}