% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/aro.smooth.tool.r
\name{aro.smooth.tool}
\alias{aro.smooth.tool}
\title{aro.smooth.tool}
\usage{
aro.smooth.tool(model, SL.set, L.set, algorithms = c("taubin", "angweight",
  "fujilaplace", "laplace", "hclaplace"), iter = 10, tarface,
  deltaFJ = NULL, deltaAW = NULL, lambda = c(0.01, 0.05, 0.1, 0.15, 0.2),
  tau = 0.01, lambda.levels = 5, deltaFJ.levels = 5, deltaAW.levels = 5,
  lambda.start = 0.95, deltaFJ.start = 0.95, deltaAW.start = 0.95,
  lambda.f = 0.99, deltaFJ.f = 0.99, deltaAW.f = 0.99, lambda.iter = 70,
  l.lambda.iter = 7, deltaFJ.iter = 70, l.deltaFJ.iter = 7,
  deltaAW.iter = 70, l.deltaAW.iter = 7, num.cores = NULL,
  iter_scale_tau = 1, iter_scale_fuj = 1, iter_scale_ang = 1)
}
\arguments{
\item{model}{triangular mesh stored as object of class "mesh3d"}

\item{SL.set}{character: kxm matrix semi-landmark set}

\item{L.set}{character: kxm matrix landmark set}

\item{algorithms}{character: algorithm types stored in Morpho::vcgSmooth}

\item{iter}{numeric: number of smoothing iterations (less than 10 recommended)}

\item{tarface}{numeric: target number of triangles for the mesh decimation}

\item{deltaFJ}{numeric: delta values for fujiLaplace algorithm (if NULL an automatic estimation will be performed)}

\item{deltaAW}{numeric: delta values for angWeight algorithm (if NULL an automatic estimation will be performed)}

\item{lambda}{numeric: lambda value (if NULL an automatic estimation will be performed)}

\item{tau}{numeric: mu value for "taubin" algorithm}

\item{lambda.levels}{numeric: range length for lambda}

\item{deltaFJ.levels}{numeric: range length for deltaFJ}

\item{deltaAW.levels}{numeric: range length for deltaAW}

\item{lambda.start}{numeric: upper value for the range of lambda}

\item{deltaFJ.start}{numeric: upper value for the range of deltaFJ}

\item{deltaAW.start}{numeric: upper value for the range of deltaAW}

\item{lambda.f}{numeric: factor for the estimation of lambda}

\item{deltaFJ.f}{numeric: factor for the estimation of deltaFJ}

\item{deltaAW.f}{numeric: factor for the estimation of deltaAW}

\item{lambda.iter}{numeric: number of iterations for the estimation of lambda}

\item{l.lambda.iter}{numeric: interval for lambda.iter}

\item{deltaFJ.iter}{numeric: number of iterations for the estimation of deltaFJ}

\item{l.deltaFJ.iter}{numeric: interval for deltaFJ.iter}

\item{deltaAW.iter}{numeric: number of iterations for the estimation of deltaFJ}

\item{l.deltaAW.iter}{numeric: interval for deltaAW.iter}

\item{num.cores}{numeric: number of CPUs cores, if NULL use the number of physical CPUs/cores}

\item{iter_scale_tau}{numeric: iterations used in the estimation of the scale factor for taubin algorithm}

\item{iter_scale_fuj}{numeric: iterations used in the estimation of the scale factor for fujilaplace algorithm}

\item{iter_scale_ang}{numeric: iterations used in the estimation of the scale factor for angWeight algorithm}
}
\value{
matrix_result matrix: the matrix of results (loss/retrieval of anatomical information) for each smoothing setting and iteration

CS numeric vector: Centroid Size values of the semi-landmark set for the starting surface, the decimated surface and the best smoothed surface

L_set numeric: the matrix of the landmark set on the best smoothed surface

SL_set numeric: the matrix of the semi-landmark set on the best smoothed surface

mesh best smoothed mesh
}
\description{
This function finds the optimal smoothing settings, when a mesh, a landmark set and a semi-landmark set are provided.
}
\examples{
\dontrun{
#load the example 1: mesh, and L set
data(exp.dog.mesh)
data(exp.dog.SLset)
data(exp.dog.Lset)
example=aro.smooth.tool(model=dog.mesh,SL.set=dog.SLset,L.set=dog.Lset,iter=10,tarface=2000)
}

\dontrun{
load the example 2: mesh, and L set
data(exp.teeth.mesh)
data(exp.teeth.SLset)
data(exp.teeth.Lset)
example=aro.smooth.tool(model=teeth.mesh,SL.set=teeth.SLset,L.set=teeth.Lset,iter=10,tarface=10000,lambda.iter = 350,l.lambda.iter=20,deltaFJ.iter = 350,l.deltaFJ.iter=20,deltaAW.iter = 350,l.deltaAW.iter=20)
}
\dontrun{
load the example 3: mesh, and L set
data(exp.SCP1.mesh)
data(exp.SCP1.SLset)
data(exp.SCP1.Lset)
example=aro.smooth.tool(model=SCP1.mesh,SL.set=SCP1.SLset,L.set=SCP1.Lset,iter=10,tarface=10000,lambda.iter = 150,l.lambda.iter=20,deltaFJ.iter = 150,l.deltaFJ.iter=20,deltaAW.iter = 150,l.deltaAW.iter=20)
}
}
\author{
Antonio Profico, Alessio Veneziano, Alessandro Lanteri, Paolo Piras
}

